require 'rest-client'
require 'json'

module SplitApi
  module Models
    class Attributes < BaseModel
      def initialize(config)
        @config = config
      end

      # GET /trafficTypes/{traffic_type_id}/schema
      def list(traffic_type_id)
        JSON.parse(
          RestClient.get(
            "#{@config.base_uri}/trafficTypes/#{traffic_type_id}/schema", auth_headers
          ).body
        ).map do |attribute|
          DataObjects::Attribute.new(
            description: attribute['description'],
            display_name: attribute['displayName'],
            traffic_type_id: attribute['trafficTypeId'],
            id: attribute['id'],
            organization_id: attribute['organizationId'],
            data_type: attribute['dataType'],
            is_searchable: attribute['isSearchable']
          )
        end
      end

      # PUT /trafficTypes/{traffic_type_id}/schema
      def save(attribute)
        attribute = JSON.parse(
          RestClient.put(
            "#{@config.base_uri}/trafficTypes/#{attribute[:traffic_type_id]}/schema",
            {
              'id' => attribute[:id],
              'trafficTypeId' => attribute[:traffic_type_id],
              'displayName' => attribute[:display_name],
              'description' => attribute[:description],
              'dataType' => attribute[:data_type]
            }.to_json, auth_headers
          ).body
        )

        DataObjects::Attribute.new(
          description: attribute['description'],
          display_name: attribute['displayName'],
          traffic_type_id: attribute['trafficTypeId'],
          id: attribute['id'],
          organization_id: attribute['organizationId'],
          data_type: attribute['dataType'],
          is_searchable: attribute['isSearchable']
        )
      end

      # DELETE /trafficTypes/{traffic_type_id}/schema/{attribute_id}
      def delete(traffic_type_id, attribute_id)
        RestClient.delete(
          "#{@config.base_uri}/trafficTypes/#{traffic_type_id}" \
          "/schema/#{attribute_id}",
          auth_headers) == 'true'
      end
    end
  end
end
