require 'rest-client'
require 'json'

module SplitApi
  module Models
    class Identities < BaseModel
      def initialize(config)
        @config = config
      end

      # PUT /trafficTypes/{traffic_type_id}/environments/{environment_id}/identities/{key}
      def save(identity)
        identity = JSON.parse(RestClient.put(
          "#{@config.base_uri}/trafficTypes/#{identity[:traffic_type_id]}" \
          "/environments/#{identity[:environment_id]}/identities/#{identity[:key]}",
          {
            'key' => identity[:key],
            'trafficTypeId' => identity[:traffic_type_id],
            'environmentId' => identity[:environment_id],
            'organizationId' => identity[:organization_id],
            'values' => identity[:values]
          }.to_json, auth_headers).body)

        DataObjects::Identity.new(
          key: identity['key'],
          traffic_type_id: identity['trafficTypeId'],
          environment_id: identity['environmentId'],
          organization_id: identity['organizationId'],
          values: identity['values']
        )
      end

      # POST /trafficTypes/{traffic_type_id}/environments/{environment_id}/identities
      def save_all(traffic_type_id, environment_id, identities)
        result = JSON.parse(RestClient.post(
          "#{@config.base_uri}/trafficTypes/#{traffic_type_id}" \
          "/environments/#{environment_id}" \
          "/identities",
          identities.to_json, auth_headers).body
        )

        objects = result['objects'].map do |identity|
          DataObjects::Identity.new(
            key: identity['key'],
            traffic_type_id: identity['trafficTypeId'],
            environment_id: identity['environmentId'],
            organization_id: identity['organizationId'],
            values: identity['values']
          )
        end

        {
          objects: objects,
          failed: result['failed'],
          metadata: result['metadata']
        }
      end

      # PATCH /trafficTypes/{traffic_type_id}/environments/{environment_id}/identities/{key}
      def update(identity)
        identity = JSON.parse(RestClient.patch(
          "#{@config.base_uri}/trafficTypes/#{identity[:traffic_type_id]}" \
          "/environments/#{identity[:environment_id]}/identities/#{identity[:key]}",
          {
            'key' => identity[:key],
            'trafficTypeId' => identity[:traffic_type_id],
            'environmentId' => identity[:environment_id],
            'organizationId' => identity[:organization_id],
            'values' => identity[:values]
          }.to_json, auth_headers).body)

        DataObjects::Identity.new(
          key: identity['key'],
          traffic_type_id: identity['trafficTypeId'],
          environment_id: identity['environmentId'],
          organization_id: identity['organizationId'],
          values: identity['values']
        )
      end

      # DELETE /trafficTypes/{traffic_type_id}/environments/{environment_id}/identities/{key}
      def delete(traffic_type_id, environment_id, key)
        RestClient.delete(
          "#{@config.base_uri}/trafficTypes/#{traffic_type_id}/environments/" \
          "#{environment_id}/identities/#{key}",
          auth_headers) == 'true'
      end
    end
  end
end
